==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PersistentVolumeClaimStatusBuilder extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus,io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusBuilder>{
  public PersistentVolumeClaimStatusBuilder() {
    this(false);
  }
  public PersistentVolumeClaimStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new PersistentVolumeClaimStatus(), validationEnabled);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PersistentVolumeClaimStatus(), validationEnabled);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance) {
    this(fluent, instance, false);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessModes(instance.getAccessModes()); 
    fluent.withCapacity(instance.getCapacity()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withPhase(instance.getPhase()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance) {
    this(instance,false);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessModes(instance.getAccessModes()); 
    this.withCapacity(instance.getCapacity()); 
    this.withConditions(instance.getConditions()); 
    this.withPhase(instance.getPhase()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus build() {
    PersistentVolumeClaimStatus buildable = new PersistentVolumeClaimStatus(fluent.getAccessModes(),fluent.getCapacity(),fluent.getConditions(),fluent.getPhase());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeClaimStatusBuilder that = (PersistentVolumeClaimStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PersistentVolumeClaimStatusBuilder extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluentImpl<io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus,io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusBuilder>{
  public PersistentVolumeClaimStatusBuilder() {
    this(false);
  }
  public PersistentVolumeClaimStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new PersistentVolumeClaimStatus(), validationEnabled);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PersistentVolumeClaimStatus(), validationEnabled);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance) {
    this(fluent, instance, false);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessModes(instance.getAccessModes()); 
    fluent.withAllocatedResources(instance.getAllocatedResources()); 
    fluent.withCapacity(instance.getCapacity()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withPhase(instance.getPhase()); 
    fluent.withResizeStatus(instance.getResizeStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance) {
    this(instance,false);
  }
  public PersistentVolumeClaimStatusBuilder(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessModes(instance.getAccessModes()); 
    this.withAllocatedResources(instance.getAllocatedResources()); 
    this.withCapacity(instance.getCapacity()); 
    this.withConditions(instance.getConditions()); 
    this.withPhase(instance.getPhase()); 
    this.withResizeStatus(instance.getResizeStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus build() {
    PersistentVolumeClaimStatus buildable = new PersistentVolumeClaimStatus(fluent.getAccessModes(),fluent.getAllocatedResources(),fluent.getCapacity(),fluent.getConditions(),fluent.getPhase(),fluent.getResizeStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeClaimStatusBuilder that = (PersistentVolumeClaimStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
